@@ -8,7 +8,7 @@ pushd gems
 
   gemfile=$(ls *.gem | head -n1)
   sha256sum ${gemfile}
-  gem install ${gemfile}
+  gem install --no-document ${gemfile}
   gem list -d nokogiri
   nokogiri -v
 
@@ -30,3 +30,9 @@ pushd nokogiri
   fi
 
 popd
+
+# cd out of the dir with the Gemfile and Gemfile.lock
+# because that's confusing to older versions of rubygems (e.g., bionic32)
+if [[ -e nokogiri/scripts/test-nokogumbo-compatibility ]] ; then
+  nokogiri/scripts/test-nokogumbo-compatibility
+fi
