@@ -61,14 +61,14 @@ module Nokogiri
           end
           rd.close
         end
-        sleep(1)              # sleep for one second to make sure the reader will actually block for input
+        sleep(0.1) # sleep to make sure the reader will actually block for input
         begin
           wr.puts "<foo>"
           wr.puts "<bar/>" * 10000
           wr.flush
         rescue Errno::EPIPE
         end
-        res = t.join(5)    # wait 5 seconds for the thread to finish
+        res = t.join(1) # give the thread a moment to finish
         wr.close
         refute_nil node_out, "Didn't read any nodes, exclude the trivial case"
         refute_nil res, "Reader blocks trying to read the entire stream"
@@ -206,7 +206,7 @@ module Nokogiri
       end
 
       def test_pushing_to_non_array_raises_TypeError
-        skip "TODO: JRuby ext does not internally call `errors`" if Nokogiri.jruby?
+        skip_unless_libxml2("TODO: JRuby ext does not internally call `errors`")
         reader = Nokogiri::XML::Reader(StringIO.new('&bogus;'))
         def reader.errors
           1
@@ -419,6 +419,28 @@ module Nokogiri
                       reader.map(&:namespace_uri))
       end
 
+      def test_reader_node_attributes_keep_a_reference_to_the_reader
+        skip_unless_libxml2("valgrind tests should only run with libxml2")
+
+        attribute_nodes = []
+
+        refute_valgrind_errors do
+          xml = <<~EOF
+            <root>
+              <content first_name="bob" last_name="loblaw"/>
+            </root>
+          EOF
+
+          reader = Nokogiri::XML::Reader.from_memory(xml)
+          reader.each do |element|
+            attribute_nodes += element.attribute_nodes
+          end
+        end
+
+        assert_operator(attribute_nodes.length, :>, 0)
+        attribute_nodes.inspect
+      end
+
       def test_namespaced_attributes
         reader = Nokogiri::XML::Reader.from_memory(<<-eoxml)
         <x xmlns:edi='http://ecommerce.example.org/schema' xmlns:commons="http://rets.org/xsd/RETSCommons">
