@@ -317,31 +317,35 @@ module Nokogiri
       end
 
       def test_custom_xpath_handler_with_args_under_gc_pressure
-        # see http://github.com/sparklemotion/nokogiri/issues/#issue/345
-        tool_inspector = Class.new do
-          def name_equals(nodeset, name, *args)
-            nodeset.all? do |node|
-              args.each { |thing| thing.inspect }
-              node["name"] == name
+        skip_unless_libxml2("valgrind tests should only run with libxml2")
+
+        refute_valgrind_errors do
+          # see http://github.com/sparklemotion/nokogiri/issues/#issue/345
+          tool_inspector = Class.new do
+            def name_equals(nodeset, name, *args)
+              nodeset.all? do |node|
+                args.each { |thing| thing.inspect }
+                node["name"] == name
+              end
             end
-          end
-        end.new
+          end.new
 
-        xml = <<-EOXML
-          <toolbox>
-            #{"<tool name='hammer'/><tool name='wrench'/>" * 10}
-          </toolbox>
-        EOXML
-        doc = Nokogiri::XML xml
+          xml = <<~EOXML
+            <toolbox>
+              #{"<tool name='hammer'/><tool name='wrench'/>" * 10}
+            </toolbox>
+          EOXML
+          doc = Nokogiri::XML xml
 
-        # long list of long arguments, to apply GC pressure during
-        # ruby_funcall argument marshalling
-        xpath = ["//tool[name_equals(.,'hammer'"]
-        1000.times { xpath << "'unused argument #{'x' * 1000}'" }
-        xpath << "'unused argument')]"
-        xpath = xpath.join(',')
+          # long list of long arguments, to apply GC pressure during
+          # ruby_funcall argument marshalling
+          xpath = ["//tool[name_equals(.,'hammer'"]
+          500.times { xpath << "'unused argument #{'x' * 1000}'" }
+          xpath << "'unused argument')]"
+          xpath = xpath.join(',')
 
-        assert_equal doc.xpath("//tool[@name='hammer']"), doc.xpath(xpath, tool_inspector)
+          assert_equal doc.xpath("//tool[@name='hammer']"), doc.xpath(xpath, tool_inspector)
+        end
       end
 
       def test_custom_xpath_without_arguments
@@ -466,6 +470,27 @@ module Nokogiri
         end
       end
 
+      def test_huge_xpath_query
+        if Nokogiri.uses_libxml?("~>2.9.11") && !Nokogiri::VERSION_INFO["libxml"]["patches"]&.include?("0007-Fix-XPath-recursion-limit.patch")
+          skip("libxml2 under test is broken with respect to xpath query recusion depth")
+        end
+
+        # real world example
+        # from https://github.com/sparklemotion/nokogiri/issues/2257
+        query = File.read(File.join(ASSETS_DIR, 'huge-xpath-query.txt'))
+
+        doc = Nokogiri::XML::Document.parse("<root></root>")
+        handler = Class.new do
+          def seconds(context)
+            42
+          end
+          def add(context, rhs)
+            42
+          end
+        end
+        doc.xpath(query, {"ct" => "https://test.nokogiri.org/ct", "date" => "https://test.nokogiri.org/date"}, handler.new)
+      end
+
       describe "nokogiri-builtin:css-class xpath function" do
         before do
           @doc = Nokogiri::HTML::Document.parse("<html></html>")
